@@ -713,22 +713,22 @@ lat/lon values returned by grid method may be incorrect."""
                     lonsperlat = self.grid_definition_list
                     if ma.isMA(fld):
                         fld = ma.filled(fld)
-                        fld = _redtoreg(nx, lonsperlat,\
-                                fld.astype('f8'), fill_value)
+                        fld = _redtoreg(nx, lonsperlat.astype(np.long),\
+                                fld.astype(np.double), fill_value)
                         fld = ma.masked_values(fld,fill_value)
                     else:
-                        fld = _redtoreg(nx, lonsperlat, fld.astype('f8'),\
-                                fill_value)
+                        fld = _redtoreg(nx, lonsperlat.astype(np.long),\
+                                fld.astype(np.double), fill_value)
         # check scan modes for rect grids.
         if nx is not None and ny is not None:
             # rows scan in the -x direction (so flip)
-            if self.scanmodeflags[0]:
-                fldsave = fld.astype('f') # casting makes a copy
-                fld[:,:] = fldsave[:,::-1]
+            #if self.scanmodeflags[0]:
+            #    fldsave = fld.astype('f') # casting makes a copy
+            #    fld[:,:] = fldsave[:,::-1]
             # columns scan in the -y direction (so flip)
-            if not self.scanmodeflags[1]:
-                fldsave = fld.astype('f') # casting makes a copy
-                fld[:,:] = fldsave[::-1,:]
+            #if not self.scanmodeflags[1]:
+            #    fldsave = fld.astype('f') # casting makes a copy
+            #    fld[:,:] = fldsave[::-1,:]
             # adjacent rows scan in opposite direction.
             # (flip every other row)
             if self.scanmodeflags[3]:
@@ -768,10 +768,10 @@ lat/lon values returned by grid method may be incorrect."""
             lats = np.arange(lat1,lat2+delat,delat)
             lons = np.arange(lon1,lon2+delon,delon)
             # flip if scan mode says to.
-            if self.scanmodeflags[0]:
-                lons = lons[::-1]
-            if not self.scanmodeflags[1]:
-                lats = lats[::-1]
+            #if self.scanmodeflags[0]:
+            #    lons = lons[::-1]
+            #if not self.scanmodeflags[1]:
+            #    lats = lats[::-1]
             projparams['proj'] = 'cyl'
             lons,lats = np.meshgrid(lons,lats) # make 2-d arrays.
         elif gdtnum == 40: # gaussian grid (only works for global!)
@@ -790,10 +790,10 @@ lat/lon values returned by grid method may be incorrect."""
             if lat1 < lat2:  # reverse them if necessary
                 lats = lats[::-1]
             # flip if scan mode says to.
-            if self.scanmodeflags[0]:
-                lons = lons[::-1]
-            if not self.scanmodeflags[1]:
-                lats = lats[::-1]
+            #if self.scanmodeflags[0]:
+            #    lons = lons[::-1]
+            #if not self.scanmodeflags[1]:
+            #    lats = lats[::-1]
             projparams['proj'] = 'cyl'
             lons,lats = np.meshgrid(lons,lats) # make 2-d arrays
         # mercator, lambert conformal, stereographic, albers equal area, azimuthal equidistant
@@ -1396,14 +1396,14 @@ class Grib2Encode:
         # reorder array to be consistent with
         # specified scan order.
         if self.scanmodeflags is not None:
-            if self.scanmodeflags[0]:
-            # rows scan in the -x direction (so flip)
-                fieldsave = field.astype('f') # casting makes a copy
-                field[:,:] = fieldsave[:,::-1]
-            # columns scan in the -y direction (so flip)
-            if not self.scanmodeflags[1]:
-                fieldsave = field.astype('f') # casting makes a copy
-                field[:,:] = fieldsave[::-1,:]
+            #if self.scanmodeflags[0]:
+            ## rows scan in the -x direction (so flip)
+            #    fieldsave = field.astype('f') # casting makes a copy
+            #    field[:,:] = fieldsave[:,::-1]
+            ## columns scan in the -y direction (so flip)
+            #if not self.scanmodeflags[1]:
+            #    fieldsave = field.astype('f') # casting makes a copy
+            #    field[:,:] = fieldsave[::-1,:]
             # adjacent rows scan in opposite direction.
             # (flip every other row)
             if self.scanmodeflags[3]:
